@@ -1,8 +1,8 @@
 import os
 from requests import Session
-from Step import Step
+from libs3tl import Step
 
-class Load(Step): 
+class Load(Step.Step): 
     
     def __init__(self):
         self.setStartTime()
