@@ -2,10 +2,10 @@ import inspect
 import json
 import os
 import time
-from Step import Step
+from libs3tl import Step
 import pandas as pd
 
-class Transform(Step):
+class Transform(Step.Step):
     def __init__(self):
         self.setStartTime()
         self.step = "Tr"
